Janus-Kafka
Kafka adapter for Janus.
Macros
- opts
instrumentedCreate an [Opts].
Structs
- Publishes messages to Kafka
- Allows a healthcheck to be performed on the Kafka publisher.
- Consumes messages from Kafka
- Allows a healthcheck to be performed on the Kafka subscriber.
- OffsetError is raised when an
Offsetcan’t be created from aString. - Opts
instrumentedA struct that bundles the options for creating mostMetrictypes. - Acknowledges messages from the Publisher.
- Configuration options for a Publisher
- A
Messageto be published to Kafka. - Acknowledges messages from the Subscriber.
- Configuration options for a Subscriber
- Tokio
Runtime tokio-rtAnAsyncRuntimeimplementation backed by Tokio.
Enums
- Respresents all errors.
- Position for the offset when no initial value.
Traits
- Message extension methods for Kafka messages
Functions
- instrumented_
publisher_ ack_ handler instrumentedAwaits each future returned by the ack handler and increments a metric. A convenience function to continuously processes acks until an error is encountered. - instrumented_
subscriber_ ack_ handler instrumentedFor each ack increments a metric depending on the variant in the result. A convenience function to continuously processes acks until an error is encountered. - Awaits each future returned by the publisher ack handler.
- Acknowledges each ack, if the result variant is an error, the error is propagated.